@@ -31,13 +31,12 @@ from cognite_toolkit._cdf_tk.apps import (
     MigrateApp,
     ModulesApp,
     ProfileApp,
-    PurgeApp,
     RepoApp,
     RunApp,
 )
 from cognite_toolkit._cdf_tk.cdf_toml import CDFToml
 from cognite_toolkit._cdf_tk.commands import (
-    CollectCommand,
+    AboutCommand,
 )
 from cognite_toolkit._cdf_tk.constants import HINT_LEAD_TEXT, URL, USE_SENTRY
 from cognite_toolkit._cdf_tk.exceptions import (
@@ -99,10 +98,8 @@ if Plugins.run.value.is_enabled():
 if Plugins.dump.value.is_enabled():
     _app.add_typer(DumpApp(**default_typer_kws), name="dump")
 
-if Plugins.purge.value.is_enabled() and not Flags.v07.is_enabled():
-    _app.add_typer(PurgeApp(**default_typer_kws), name="purge")
 
-if Plugins.dev.value.is_enabled() and Flags.v07.is_enabled():
+if Plugins.dev.value.is_enabled():
     _app.add_typer(DevApp(**default_typer_kws), name="dev")
 
 if Flags.PROFILE.is_enabled():
@@ -111,13 +108,20 @@ if Flags.PROFILE.is_enabled():
 if Flags.MIGRATE.is_enabled():
     _app.add_typer(MigrateApp(**default_typer_kws), name="migrate")
 
-if Flags.v07.is_enabled():
+if Plugins.data.value.is_enabled():
     _app.add_typer(DataApp(**default_typer_kws), name="data")
 
 _app.add_typer(ModulesApp(**default_typer_kws), name="modules")
 _app.command("init")(landing_app.main_init)
 
 
+@_app.command("about")
+def about() -> None:
+    """Display information about the Toolkit installation and configuration."""
+    cmd = AboutCommand()
+    cmd.run(lambda: cmd.execute(Path.cwd()))
+
+
 def app() -> NoReturn:
     # --- Main entry point ---
     # Users run 'app()' directly, but that doesn't allow us to control excepton handling:
@@ -150,17 +154,6 @@ def app() -> NoReturn:
     raise SystemExit(0)
 
 
-@_app.command("collect", hidden=True)
-def collect(
-    action: str = typer.Argument(
-        help="Whether to explicitly opt-in or opt-out of usage data collection. [opt-in, opt-out]"
-    ),
-) -> None:
-    """Collect usage information for the toolkit."""
-    cmd = CollectCommand()
-    cmd.run(lambda: cmd.execute(action))  # type: ignore [arg-type]
-
-
 @user_app.callback(invoke_without_command=True)
 def user_main(ctx: typer.Context) -> None:
     """Commands to give information about the toolkit."""
