@@ -11,7 +11,6 @@ from cognite_toolkit._cdf_tk.client.data_classes.location_filters import (
     LocationFilter,
     LocationFilterList,
     LocationFilterWrite,
-    LocationFilterWriteList,
 )
 from cognite_toolkit._cdf_tk.constants import BUILD_FOLDER_ENCODING
 from cognite_toolkit._cdf_tk.cruds._base_cruds import ResourceCRUD
@@ -28,15 +27,10 @@ from .timeseries import TimeSeriesCRUD
 
 
 @final
-class LocationFilterCRUD(
-    ResourceCRUD[str, LocationFilterWrite, LocationFilter, LocationFilterWriteList, LocationFilterList]
-):
+class LocationFilterCRUD(ResourceCRUD[str, LocationFilterWrite, LocationFilter]):
     folder_name = "locations"
-    filename_pattern = r"^.*LocationFilter$"
     resource_cls = LocationFilter
     resource_write_cls = LocationFilterWrite
-    list_cls = LocationFilterList
-    list_write_cls = LocationFilterWriteList
     yaml_cls = LocationYAML
     dependencies = frozenset(
         {
@@ -182,10 +176,7 @@ class LocationFilterCRUD(
                 *e.args[1:],
             ) from None
 
-    def create(self, items: LocationFilterWrite | LocationFilterWriteList) -> LocationFilterList:
-        if isinstance(items, LocationFilterWrite):
-            items = LocationFilterWriteList([items])
-
+    def create(self, items: Sequence[LocationFilterWrite]) -> LocationFilterList:
         created: list[LocationFilter] = []
         # Note: the Location API does not support batch creation, so we need to do this one by one.
         # Furthermore, we could not do the parentExternalId->parentId lookup before the parent was created,
@@ -213,10 +204,7 @@ class LocationFilterCRUD(
         _recursive_find(all_locations)
         return LocationFilterList(found_locations)
 
-    def update(self, items: LocationFilterWrite | LocationFilterWriteList) -> LocationFilterList:
-        if isinstance(items, LocationFilterWrite):
-            items = LocationFilterWriteList([items])
-
+    def update(self, items: Sequence[LocationFilterWrite]) -> LocationFilterList:
         updated = []
         ids = {item.external_id: item.id for item in self.retrieve([item.external_id for item in items])}
         for update in items:
