@@ -9,11 +9,9 @@ from cognite.client.data_classes import (
     DatapointSubscriptionList,
     DataPointSubscriptionUpdate,
     DataPointSubscriptionWrite,
-    DatapointSubscriptionWriteList,
     TimeSeries,
     TimeSeriesList,
     TimeSeriesWrite,
-    TimeSeriesWriteList,
 )
 from cognite.client.data_classes.capabilities import (
     Capability,
@@ -43,14 +41,11 @@ from .data_organization import DataSetsCRUD
 
 
 @final
-class TimeSeriesCRUD(ResourceContainerCRUD[str, TimeSeriesWrite, TimeSeries, TimeSeriesWriteList, TimeSeriesList]):
+class TimeSeriesCRUD(ResourceContainerCRUD[str, TimeSeriesWrite, TimeSeries]):
     item_name = "datapoints"
     folder_name = "timeseries"
-    filename_pattern = r"^(?!.*DatapointSubscription$).*"
     resource_cls = TimeSeries
     resource_write_cls = TimeSeriesWrite
-    list_cls = TimeSeriesList
-    list_write_cls = TimeSeriesWriteList
     yaml_cls = TimeSeriesYAML
     kind = "TimeSeries"
     dependencies = frozenset({DataSetsCRUD, GroupAllScopedCRUD, AssetCRUD})
@@ -125,7 +120,7 @@ class TimeSeriesCRUD(ResourceContainerCRUD[str, TimeSeriesWrite, TimeSeries, Tim
             dumped["assetExternalId"] = self.client.lookup.assets.external_id(asset_id)
         return dumped
 
-    def create(self, items: TimeSeriesWriteList) -> TimeSeriesList:
+    def create(self, items: Sequence[TimeSeriesWrite]) -> TimeSeriesList:
         return self.client.time_series.create(items)
 
     def retrieve(self, ids: SequenceNotStr[str | int]) -> TimeSeriesList:
@@ -134,7 +129,7 @@ class TimeSeriesCRUD(ResourceContainerCRUD[str, TimeSeriesWrite, TimeSeries, Tim
             ids=internal_ids, external_ids=external_ids, ignore_unknown_ids=True
         )
 
-    def update(self, items: TimeSeriesWriteList) -> TimeSeriesList:
+    def update(self, items: Sequence[TimeSeriesWrite]) -> TimeSeriesList:
         return self.client.time_series.update(items, mode="replace")
 
     def delete(self, ids: SequenceNotStr[str | int]) -> int:
@@ -182,16 +177,11 @@ class DatapointSubscriptionCRUD(
         str,
         DataPointSubscriptionWrite,
         DatapointSubscription,
-        DatapointSubscriptionWriteList,
-        DatapointSubscriptionList,
     ]
 ):
     folder_name = "timeseries"
-    filename_pattern = r"^.*DatapointSubscription$"  # Matches all yaml files who end with *DatapointSubscription.
     resource_cls = DatapointSubscription
     resource_write_cls = DataPointSubscriptionWrite
-    list_cls = DatapointSubscriptionList
-    list_write_cls = DatapointSubscriptionWriteList
     kind = "DatapointSubscription"
     _doc_url = "Data-point-subscriptions/operation/postSubscriptions"
     dependencies = frozenset(
@@ -253,7 +243,7 @@ class DatapointSubscriptionCRUD(
 
         return TimeSeriesSubscriptionsAcl(actions, scope)
 
-    def create(self, items: DatapointSubscriptionWriteList) -> DatapointSubscriptionList:
+    def create(self, items: Sequence[DataPointSubscriptionWrite]) -> DatapointSubscriptionList:
         created_list = DatapointSubscriptionList([])
         for item in items:
             to_create, batches = self.create_split_timeseries_ids(item)
@@ -271,7 +261,7 @@ class DatapointSubscriptionCRUD(
                 items.append(retrieved)
         return items
 
-    def update(self, items: DatapointSubscriptionWriteList) -> DatapointSubscriptionList:
+    def update(self, items: Sequence[DataPointSubscriptionWrite]) -> DatapointSubscriptionList:
         updated_list = DatapointSubscriptionList([])
         for item in items:
             current = self.client.time_series.subscriptions.list_member_time_series(item.external_id, limit=-1)
