@@ -1,13 +1,9 @@
 from pydantic import Field
 
+from .authentication import AuthenticationClientIdSecret
 from .base import ToolkitResource
 
 
-class AuthenticationClientIdSecret(ToolkitResource):
-    client_id: str = Field(description="Client Id.")
-    client_secret: str = Field(description="Client Secret.")
-
-
 class FunctionScheduleYAML(ToolkitResource):
     function_external_id: str = Field(
         description="The external ID provided by the client for the function.",
