@@ -12,6 +12,7 @@ from ._readers import (
     CSVReader,
     FailedParsing,
     FileReader,
+    MultiFileReader,
     NDJsonReader,
     ParquetReader,
     YAMLReader,
@@ -45,6 +46,7 @@ __all__ = [
     "FileReader",
     "FileWriter",
     "GzipCompression",
+    "MultiFileReader",
     "NDJsonReader",
     "NDJsonWriter",
     "ParquetReader",
