@@ -38,7 +38,7 @@ class FileReader(FileIO, ABC):
     @abstractmethod
     def _read_chunks_from_file(self, file: TextIOWrapper) -> Iterator[dict[str, JsonVal]]:
         """Read chunks from the file."""
-        raise NotImplementedError("This method should be implemented in subclasses.")
+        ...
 
     @classmethod
     def from_filepath(cls, filepath: Path) -> "type[FileReader]":
@@ -62,6 +62,11 @@ class FileReader(FileIO, ABC):
             f"Unknown file format: {suffix}. Available formats: {humanize_collection(FILE_READ_CLS_BY_FORMAT.keys())}."
         )
 
+    @abstractmethod
+    def count(self) -> int:
+        """Count the number of chunks in the file."""
+        ...
+
 
 class MultiFileReader(FileReader):
     """Reads multiple files and yields chunks from each file sequentially.
@@ -112,6 +117,14 @@ class MultiFileReader(FileReader):
     def _read_chunks_from_file(self, file: TextIOWrapper) -> Iterator[dict[str, JsonVal]]:
         raise NotImplementedError("This method is not used in MultiFileReader.")
 
+    def count(self) -> int:
+        """Count the total number of chunks in all files."""
+        total_count = 0
+        for input_file in self.input_files:
+            reader = self.reader_class(input_file)
+            total_count += reader.count()
+        return total_count
+
 
 class NDJsonReader(FileReader):
     FORMAT = ".ndjson"
@@ -121,11 +134,25 @@ class NDJsonReader(FileReader):
             if stripped := line.strip():
                 yield json.loads(stripped)
 
+    def count(self) -> int:
+        """Count the number of lines (chunks) in the NDJSON file."""
+        compression = Compression.from_filepath(self.input_file)
+        with compression.open("r") as file:
+            line_count = sum(1 for line in file if line.strip())
+        return line_count
+
 
 class YAMLBaseReader(FileReader, ABC):
     def _read_chunks_from_file(self, file: TextIOWrapper) -> Iterator[dict[str, JsonVal]]:
         yield from yaml.safe_load_all(file)
 
+    def count(self) -> int:
+        """Count the number of documents (chunks) in the YAML file."""
+        compression = Compression.from_filepath(self.input_file)
+        with compression.open("r") as file:
+            doc_count = sum(1 for _ in yaml.safe_load_all(file))
+        return doc_count
+
 
 class YAMLReader(YAMLBaseReader):
     FORMAT = ".yaml"
@@ -306,6 +333,13 @@ class CSVReader(TableReader):
                 raise ToolkitValueError(f"No data found in the file: {input_file.as_posix()!r}.")
         return column_names, sample_rows
 
+    def count(self) -> int:
+        """Count the number of rows in the CSV file."""
+        compression = Compression.from_filepath(self.input_file)
+        with compression.open("r") as file:
+            line_count = sum(1 for _ in file) - 1  # Subtract 1 for header
+        return line_count
+
 
 class ParquetReader(TableReader):
     FORMAT = ".parquet"
@@ -359,6 +393,13 @@ class ParquetReader(TableReader):
                 raise ToolkitValueError(f"No data found in the file: {input_file.as_posix()!r}.")
         return column_names, sample_rows
 
+    def count(self) -> int:
+        """Count the number of rows in the Parquet file."""
+        import pyarrow.parquet as pq
+
+        with pq.ParquetFile(self.input_file) as parquet_file:
+            return parquet_file.metadata.num_rows
+
 
 FILE_READ_CLS_BY_FORMAT: Mapping[str, type[FileReader]] = {}
 TABLE_READ_CLS_BY_FORMAT: Mapping[str, type[TableReader]] = {}
